@@ -1,4 +1,4 @@
-# Copyright (C) 2012-2016 Julie Marchant <onpon4@riseup.net>
+# Copyright (C) 2012-2017 Julie Marchant <onpon4@riseup.net>
 #
 # This file is part of the Pygame SGE.
 #
@@ -235,12 +235,21 @@ from __future__ import absolute_import
 from __future__ import print_function
 from __future__ import unicode_literals
 
-__version__ = "1.4.2"
+__version__ = "1.4.4"
 
 import sys
 import os
 
-import pygame
+try:
+    import pygame
+except ImportError as e:
+    try:
+        import pygame_sdl2
+    except ImportError:
+        raise e
+    else:
+        pygame_sdl2.import_as_pygame()
+        import pygame
 
 # Constants
 IMPLEMENTATION = "Pygame SGE"
