@@ -1,4 +1,4 @@
-# Copyright (C) 2012-2016 Julie Marchant <onpon4@riseup.net>
+# Copyright (C) 2012-2017 Julie Marchant <onpon4@riseup.net>
 #
 # This file is part of the Pygame SGE.
 #
@@ -58,6 +58,9 @@ _active_objects = set()
 _prev_axes = {}
 _prev_hats = {}
 
+# Display info
+_display_info = None
+
 
 class cache(object):
 
@@ -110,7 +113,7 @@ def _check_color_input(value):
 def _check_color(value):
     # Make sure a value is either None or a color.
     if value is not None and not isinstance(value, sge.gfx.Color):
-        e = "`{}` is not a Color object.".format(repr(fill))
+        e = "`{}` is not a Color object.".format(repr(value))
         raise TypeError(e)
 
 
@@ -198,16 +201,15 @@ def _set_mode():
     global game_y
     game = sge.game
     game_display_surface = _scale(game_display_surface, game.width, game.height)
-    info = pygame.display.Info()
 
     if game.scale:
         game_xscale = game.scale
         game_yscale = game.scale
 
-    if game.fullscreen or not info.wm:
+    if game.fullscreen or not _display_info.wm:
         flags = pygame.FULLSCREEN | pygame.HWSURFACE | pygame.DOUBLEBUF
 
-        modes = pygame.display.list_modes()
+        modes = pygame.display.list_modes(0, flags)
         if modes == -1 or not modes:
             w = "Couldn't find out the maximum resolution! Assuming 1024x768."
             warnings.warn(w)
@@ -216,21 +218,16 @@ def _set_mode():
         force_auto_scale = False
 
         if game.scale:
-            target_width = int(game.width * game.scale)
-            target_height = int(game.height * game.scale)
-            if (target_width, target_height) in modes:
-                game_window_width = target_width
-                game_window_height = target_height
-            else:
-                for mode in reversed(modes):
-                    if mode[0] >= target_width and mode[1] >= target_height:
-                        game_window_width, game_window_height = mode
-                        break
-                else:
-                    game_window_width, game_window_height = modes[0]
-                    force_auto_scale = True
+            game_window_width = int(game.width * game.scale)
+            game_window_height = int(game.height * game.scale)
+            if not pygame.display.mode_ok(
+                    (game_window_width, game_window_height), flags):
+                game_window_width = _display_info.current_w
+                game_window_height = _display_info.current_h
+                force_auto_scale = True
         else:
-            game_window_width, game_window_height = modes[0]
+            game_window_width = _display_info.current_w
+            game_window_height = _display_info.current_h
 
         game_window = pygame.display.set_mode(
             (game_window_width, game_window_height), flags)
@@ -411,7 +408,7 @@ def _get_circle_sprite(radius, fill, outline, outline_thickness, anti_alias):
 
 
 def _get_polygon_sprite(points, fill, outline, outline_thickness, anti_alias):
-    # Return a sprite for the given rectangle.
+    # Return a sprite for the given polygon.
     i = ("poly_sprite", tuple(points),
          tuple(fill) if fill is not None else None,
          tuple(outline) if outline is not None else None,
@@ -510,15 +507,15 @@ def o_update(self, time_passed, delta_mult):
     # Update the animation frame.
     if self.image_fps and isinstance(self.sprite, sge.gfx.Sprite):
         self.rd["anim_count"] += time_passed
-        self.image_index += int(self.rd["anim_count"] / self.rd["frame_time"])
+        self.rd["image_index"] += int(self.rd["anim_count"] / self.rd["frame_time"])
         self.rd["anim_count"] %= abs(self.rd["frame_time"])
 
         if self.sprite is not None:
-            while self.image_index >= self.sprite.frames:
-                self.image_index -= self.sprite.frames
+            while self.rd["image_index"] >= self.sprite.frames:
+                self.rd["image_index"] -= self.sprite.frames
                 self.event_animation_end()
-            while self.image_index < 0:
-                self.image_index += self.sprite.frames
+            while self.rd["image_index"] < 0:
+                self.rd["image_index"] += self.sprite.frames
                 self.event_animation_end()
 
     # Alarms
@@ -1225,7 +1222,7 @@ def tg_blit(self, dest, x, y):
                     y = sy + j * self.tile_height
 
                 ssurf = s_set_transparency(sprite, sprite.rd["baseimages"][0])
-                dest.blit(ssurf, (x, y))
+                dest.blit(ssurf, (int(x), int(y)))
 
 
 def v_limit(self):
